@@ -5,8 +5,8 @@ from io import BytesIO, StringIO
 from typing import Any
 from uuid import UUID
 
-from fastadmin.schemas.api import ExportFormat
-from fastadmin.schemas.configuration import WidgetType
+from fastadmin.api.schemas import ExportFormat
+from fastadmin.models.schemas import WidgetType
 from fastadmin.settings import settings
 
 
@@ -383,30 +383,34 @@ class BaseModelAdmin:
 
         return fields
 
-    def has_add_permission(self) -> bool:
+    def has_add_permission(self, user_id: UUID | int | None = None) -> bool:
         """This method is used to check if user has permission to add new model instance.
 
+        :param user_id: The user id.
         :return: A boolean value.
         """
         return True
 
-    def has_change_permission(self) -> bool:
+    def has_change_permission(self, user_id: UUID | int | None = None) -> bool:
         """This method is used to check if user has permission to change model instance.
 
+        :param user_id: The user id.
         :return: A boolean value.
         """
         return True
 
-    def has_delete_permission(self) -> bool:
+    def has_delete_permission(self, user_id: UUID | int | None = None) -> bool:
         """This method is used to check if user has permission to delete model instance.
 
+        :param user_id: The user id.
         :return: A boolean value.
         """
         return True
 
-    def has_export_permission(self) -> bool:
+    def has_export_permission(self, user_id: UUID | int | None = None) -> bool:
         """This method is used to check if user has permission to export model instance.
 
+        :param user_id: The user id.
         :return: A boolean value.
         """
         return True
@@ -495,3 +499,6 @@ class ModelAdmin(BaseModelAdmin):
         :return: An user id or None.
         """
         raise NotImplementedError
+
+
+admin_models: dict[Any, ModelAdmin] = {}
